from zope import component

from Products.Five import BrowserView

from Products.locationaware import interfaces

class LoginFormView(BrowserView):
    """This is the implementation of a view component to aid the Plone
    'login_form'.

    The main purpose of this is to provide a URL for the login form to
    use.  This can be configured by registering another view component
    that overrides this registration.
    
      >>> from zope.publisher.browser import TestRequest
      >>> class TestContext:
      ...     def __init__(self, portal_url):
      ...         self.url = portal_url
      ...     def portal_url(self):
      ...         return self.url
      
      >>> context = TestContext('http://mysite.com/here/and/there')
      >>> request = TestRequest()
      >>> view = LoginFormView(context, request)
      >>> view.login_action
      'https://mysite.com/here/and/there/login_form'
      >>> context.url = 'http://localhost/that'
      >>> view.login_action
      'http://localhost/that/login_form'
      """
    
    @apply
    def context():
        def get(self):
            return self._context[0]
        def set(self, value):
            self._context = [value]
        return property(get, set)

    @property
    def login_action(self):
        url = self.context.portal_url()
        if not url.startswith('http://localhost'):
            url = url.replace('http://', 'https://')
        return url + '/login_form'
